# Generated by Django 2.1.3 on 2018-11-27 13:29

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admitad', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='admitadpostbackrequest',
            name='request_url',
            field=models.TextField(validators=[django.core.validators.URLValidator()], verbose_name='Request URL'),
        ),
    ]
