# Generated by Django 2.1.3 on 2018-11-27 14:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admitad', '0002_auto_20181127_1329'),
    ]

    operations = [
        migrations.AlterField(
            model_name='admitadpostbackevent',
            name='payment_type',
            field=models.CharField(choices=[('sale', 'Sale'), ('lead', 'Lead')], max_length=4, verbose_name='Payment type'),
        ),
    ]
